@@ -158,13 +158,17 @@ where
             }
         }
 
-        if upper_index < n {
+        if upper_index < n && upper_index > 0 {
             if self[upper_index].coordinate() > upper_bound {
                 upper_index -= 1;
             }
         }
 
-        let subset = &self.get_slice(lower_index..upper_index + 1);
+        if upper_index < n {
+            upper_index += 1;
+        }
+
+        let subset = &self.get_slice(lower_index..upper_index);
         subset
     }
 
@@ -179,7 +183,6 @@ where
             return &self.get_slice(0..0);
         }
 
-
         let mut lower_index = match self.search_by(lower_bound) {
             Ok(j) => j,
             Err(j) => j,
@@ -388,6 +391,21 @@ impl<P: IndexedCoordinate<C>, C> fmt::Display for PeakSetVec<P, C> {
     }
 }
 
+impl<P: IndexedCoordinate<C>, C> PartialEq for PeakSetVec<P, C> {
+    fn eq(&self, other: &Self) -> bool {
+        if self.len() != other.len() {
+            false
+        } else {
+            for (a, b) in self.iter().zip(other.iter()) {
+                if a != b {
+                    return false
+                }
+            }
+            true
+        }
+    }
+}
+
 impl<P: IndexedCoordinate<C>, C> From<Vec<P>> for PeakSetVec<P, C> {
     fn from(v: Vec<P>) -> PeakSetVec<P, C> {
         PeakSetVec::wrap(v)
@@ -558,6 +576,5 @@ mod test {
         let q = 1221.639893;
         let block = peaks.all_peaks_for(q, 0.5, MassErrorType::Absolute);
         assert_eq!(block.len(), 1);
-
     }
 }
